aboutsummaryrefslogtreecommitdiffstats
path: root/arch/arm/include/asm/mach/arch.h
diff options
context:
space:
mode:
authorRussell King <rmk+kernel@arm.linux.org.uk>2011-11-01 14:27:33 +0000
committerRussell King <rmk+kernel@arm.linux.org.uk>2011-11-10 22:30:10 +0000
commitb44c350d4104265cf3a6b4355dc1ee05c16aa5de (patch)
treee389eebe83caa3a2a2532724dc5ade66298845bd /arch/arm/include/asm/mach/arch.h
parentARM: restart: add restart hook to machine_desc record (diff)
downloadlinux-dev-b44c350d4104265cf3a6b4355dc1ee05c16aa5de.tar.xz
linux-dev-b44c350d4104265cf3a6b4355dc1ee05c16aa5de.zip
ARM: restart: allow platforms more flexibility specifying restart mode
Change 'soft_reboot' into a more generic 'restart_mode' variable, allowing the default restart mode to be specified. Acked-by: Nicolas Pitre <nico@linaro.org> Acked-by: Will Deacon <will.deacon@arm.com> Acked-by: H Hartley Sweeten <hsweeten@visionengravers.com> Signed-off-by: Russell King <rmk+kernel@arm.linux.org.uk>
Diffstat (limited to 'arch/arm/include/asm/mach/arch.h')
-rw-r--r--arch/arm/include/asm/mach/arch.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/arch/arm/include/asm/mach/arch.h b/arch/arm/include/asm/mach/arch.h
index 8aa397a5ea72..6fe6cf0895c9 100644
--- a/arch/arm/include/asm/mach/arch.h
+++ b/arch/arm/include/asm/mach/arch.h
@@ -30,10 +30,10 @@ struct machine_desc {
unsigned int video_start; /* start of video RAM */
unsigned int video_end; /* end of video RAM */
- unsigned int reserve_lp0 :1; /* never has lp0 */
- unsigned int reserve_lp1 :1; /* never has lp1 */
- unsigned int reserve_lp2 :1; /* never has lp2 */
- unsigned int soft_reboot :1; /* soft reboot */
+ unsigned char reserve_lp0 :1; /* never has lp0 */
+ unsigned char reserve_lp1 :1; /* never has lp1 */
+ unsigned char reserve_lp2 :1; /* never has lp2 */
+ char restart_mode; /* default restart mode */
void (*fixup)(struct tag *, char **,
struct meminfo *);
void (*reserve)(void);/* reserve mem blocks */